@@ -108,11 +108,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let dupes_output = args.flag_dupes_output.is_some();
     let mut dupewtr = Config::new(&args.flag_dupes_output).writer()?;
 
-    let headers = rdr.byte_headers()?.clone();
+    let headers = rdr.byte_headers()?;
     if dupes_output {
-        dupewtr.write_byte_record(&headers)?;
+        dupewtr.write_byte_record(headers)?;
     }
-    let sel = rconfig.selection(&headers)?;
+    let sel = rconfig.selection(headers)?;
 
     rconfig.write_headers(&mut rdr, &mut wtr)?;
     let mut dupe_count = 0_usize;
