@@ -321,15 +321,16 @@ static TIMEOUT_SECS: OnceLock<u64> = OnceLock::new();
 const FETCH_REPORT_PREFIX: &str = "qsv_fetch_";
 const FETCH_REPORT_SUFFIX: &str = ".fetch-report.tsv";
 
-// prioritize compression schemes. Brotli first, then gzip, then deflate, and * last
-pub static DEFAULT_ACCEPT_ENCODING: &str = "br;q=1.0, gzip;q=0.6, deflate;q=0.4, *;q=0.2";
+// prioritize compression schemes. Zstd, first, then Brotli, then gzip, then deflate, and * last
+pub static DEFAULT_ACCEPT_ENCODING: &str =
+    "zstd;q=1.0, br;q=0.8, gzip;q=0.6, deflate;q=0.4, *;q=0.2";
 
 // for governor/ratelimiter
 const MINIMUM_WAIT_MS: u64 = 10;
 const MIN_WAIT: time::Duration = time::Duration::from_millis(MINIMUM_WAIT_MS);
 
 // for --report option
-#[derive(PartialEq)]
+#[derive(PartialEq, Eq)]
 pub enum ReportKind {
     Detailed,
     Short,
@@ -378,7 +379,7 @@ impl DiskCacheConfig {
     }
 }
 
-#[derive(Debug, Default, PartialEq)]
+#[derive(Debug, Default, PartialEq, Eq)]
 pub enum CacheType {
     #[default]
     None,
@@ -475,7 +476,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
 
         if args.flag_flush_cache {
-            redis::cmd("FLUSHDB").execute(&mut redis_conn);
+            redis::cmd("FLUSHDB")
+                .exec(&mut redis_conn)
+                .map_err(|_| "Cannot flush Redis cache")?;
             info!("flushed Redis database.");
         }
         CacheType::Redis
@@ -541,7 +544,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         dynfmt_url_template = url_template.to_string();
         // first, get the fields used in the url template
         let (safe_headers, _) =
-            util::safe_header_names(&str_headers, false, false, None, "", false);
+            util::safe_header_names(&str_headers, false, false, &None, "", false);
         let formatstr_re: &'static Regex = regex_oncelock!(r"\{(?P<key>\w+)?\}");
         for format_fields in formatstr_re.captures_iter(url_template) {
             dynfmt_fields.push(format_fields.name("key").unwrap().as_str());
@@ -616,6 +619,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .brotli(true)
         .gzip(true)
         .deflate(true)
+        .zstd(true)
         .use_rustls_tls()
         .http2_adaptive_window(true)
         .connection_verbose(log_enabled!(Debug) || log_enabled!(Trace))
@@ -991,6 +995,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     }
     winfo!("{end_msg}");
 
+    // if using a Diskcache, explicitly flush it
+    // to ensure all entries are written to disk
+    if cache_type == CacheType::Disk {
+        GET_DISKCACHE_RESPONSE
+            .connection()
+            .flush()
+            .map_err(|e| CliError::Other(format!("Error flushing DiskCache: {e}")))?;
+    }
+
     Ok(wtr.flush()?)
 }
 
@@ -1047,9 +1060,10 @@ fn get_cached_response(
             .set_lifespan(diskcache_config.ttl_secs)
             .set_refresh(diskcache_config.ttl_refresh)
             .build()
-            .expect("error building disk cache");
+            .expect("error building diskcache");
         log::info!("Disk cache created - dir: {cache_dir} - ttl: {ttl_secs}",
             ttl_secs = diskcache_config.ttl_secs);
+        diskcache.remove_expired_entries().expect("error removing expired diskcache entries");
         diskcache
     }"##,
     map_error = r##"|e| CliError::Other(format!("Diskcache Error: {:?}", e))"##,
