@@ -49,7 +49,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
     if args.arg_input.to_lowercase().ends_with(".sz") {
-        return fail_clierror!("Cannot index a snappy file.");
+        return fail_incorrectusage_clierror!("Cannot index a snappy file.");
     }
 
     let pidx = match args.flag_output {
