@@ -25,9 +25,18 @@ Usage:
     qsv searchset [options] (<regexset-file>) [<input>]
     qsv searchset --help
 
-search options:
+searchset arguments:
+    <regex>                    Regular expression to match. Uses Rust regex syntax.
+                               See https://docs.rs/regex/latest/regex/index.html#syntax
+                               or https://regex101.com with the Rust flavor for more info.
+    <input>                    The CSV file to read. If not given, reads from stdin.
+
+searchset options:
     -i, --ignore-case          Case insensitive search. This is equivalent to
                                prefixing the regex with '(?i)'.
+    --literal                  Treat the regex as a literal string. This allows
+                               you to search for exact matches that even contain
+                               regex special characters.
     -s, --select <arg>         Select the columns to search. See 'qsv select -h'
                                for the full syntax.
     -v, --invert-match         Select only rows that did not match
@@ -99,6 +108,7 @@ use crate::{
 struct Args {
     arg_input:              Option<String>,
     arg_regexset_file:      String,
+    flag_literal:           bool,
     flag_select:            SelectColumns,
     flag_output:            Option<String>,
     flag_no_headers:        bool,
@@ -119,13 +129,15 @@ struct Args {
     flag_quiet:             bool,
 }
 
-fn read_regexset(filename: &String) -> io::Result<Vec<String>> {
-    match File::open(filename) {
-        Ok(f) => BufReader::new(f).lines().collect(),
-        Err(e) => Err(io::Error::new(
-            io::ErrorKind::NotFound,
-            format!("Cannot open regexset file {filename}: {e}"),
-        )),
+fn read_regexset(filename: &str, literal: bool) -> io::Result<Vec<String>> {
+    let file = File::open(filename)?;
+    let reader = BufReader::new(file);
+    let lines = reader.lines();
+
+    if literal {
+        lines.map(|line| line.map(|s| regex::escape(&s))).collect()
+    } else {
+        lines.collect()
     }
 }
 
@@ -142,7 +154,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         );
     }
 
-    let regexset = read_regexset(&args.arg_regexset_file)?;
+    let regexset = read_regexset(&args.arg_regexset_file, args.flag_literal)?;
 
     let mut regex_labels: Vec<String> = Vec::with_capacity(regexset.len());
     let labels_re = Regex::new(r".?#(?P<label>.*)$").unwrap();
