@@ -6,8 +6,8 @@ Polars SQL is a SQL dialect, converting SQL queries to fast Polars LazyFrame exp
 (see https://docs.pola.rs/user-guide/sql/intro/).
 
 For a list of SQL functions and keywords supported by Polars SQL, see
-https://github.com/pola-rs/polars/blob/rs-0.42.0/crates/polars-sql/src/functions.rs and
-https://github.com/pola-rs/polars/blob/rs-0.42.0/crates/polars-sql/src/keywords.rs.
+https://github.com/pola-rs/polars/blob/py-1.6.0/crates/polars-sql/src/functions.rs and
+https://github.com/pola-rs/polars/blob/py-1.6.0/crates/polars-sql/src/keywords.rs.
 https://docs.pola.rs/py-polars/html/reference/sql/index.html also provides a more readable
 version of the SQL functions and keywords, though be aware that it's for the Python version
 of Polars, so there will be some minor syntax differences.
@@ -203,6 +203,8 @@ sqlp options:
                               will be skipped. If not set, the query will fail.
                               Only use this when debugging queries, as Polars does batched
                               parsing and will skip the entire batch where the error occurred.
+                              To get more detailed error messages, set the environment variable
+                              POLARS_BACKTRACE_IN_ERR=1 before running the query.
     --rnull-values <arg>      The comma-delimited list of case-sensitive strings to consider as
                               null values when READING CSV files (e.g. NULL, NONE, <empty string>).
                               Use "<empty string>" to consider an empty string a null value.
@@ -260,10 +262,11 @@ use std::{
 };
 
 use polars::{
+    datatypes::PlSmallStr,
     io::avro::{AvroWriter, Compression as AvroCompression},
     prelude::{
         CsvWriter, DataFrame, GzipLevel, IpcCompression, IpcWriter, JsonFormat, JsonWriter,
-        LazyCsvReader, LazyFileListReader, NullValues, OptState, ParquetCompression, ParquetWriter,
+        LazyCsvReader, LazyFileListReader, NullValues, OptFlags, ParquetCompression, ParquetWriter,
         SerWriter, StatisticsOptions, ZstdLevel,
     },
     sql::SQLContext,
@@ -559,15 +562,15 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
 
     let rnull_values = if args.flag_rnull_values == "<empty string>" {
-        vec![String::new()]
+        vec![PlSmallStr::EMPTY]
     } else {
         args.flag_rnull_values
             .split(',')
             .map(|value| {
                 if value == "<empty string>" {
-                    String::new()
+                    PlSmallStr::EMPTY
                 } else {
-                    value.to_string()
+                    PlSmallStr::from_str(value)
                 }
             })
             .collect()
@@ -589,26 +592,29 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     };
 
     let comment_char = if let Ok(comment_char) = env::var("QSV_COMMENT_CHAR") {
-        Some(comment_char)
+        Some(PlSmallStr::from_string(comment_char))
     } else {
         None
     };
 
-    let mut optimization_state = polars::lazy::frame::OptState::default();
-    optimization_state |= OptState::PROJECTION_PUSHDOWN
-        | OptState::PREDICATE_PUSHDOWN
-        | OptState::CLUSTER_WITH_COLUMNS
-        | OptState::TYPE_COERCION
-        | OptState::SIMPLIFY_EXPR
-        | OptState::FILE_CACHING
-        | OptState::SLICE_PUSHDOWN
-        | OptState::COMM_SUBEXPR_ELIM
-        | OptState::FAST_PROJECTION
-        | OptState::ROW_ESTIMATE;
+    let mut optflags = OptFlags::from_bits_truncate(0);
+    if args.flag_no_optimizations {
+        optflags |= OptFlags::TYPE_COERCION;
+    } else {
+        optflags |= OptFlags::PROJECTION_PUSHDOWN
+            | OptFlags::PREDICATE_PUSHDOWN
+            | OptFlags::CLUSTER_WITH_COLUMNS
+            | OptFlags::TYPE_COERCION
+            | OptFlags::SIMPLIFY_EXPR
+            | OptFlags::FILE_CACHING
+            | OptFlags::SLICE_PUSHDOWN
+            | OptFlags::COMM_SUBPLAN_ELIM
+            | OptFlags::COMM_SUBEXPR_ELIM
+            | OptFlags::ROW_ESTIMATE
+            | OptFlags::FAST_PROJECTION;
+    };
 
-    if args.flag_streaming {
-        optimization_state |= OptState::NEW_STREAMING;
-    }
+    optflags.set(OptFlags::STREAMING, args.flag_streaming);
 
     // check if the input is a SQL script (ends with .sql)
     let is_sql_script = std::path::Path::new(&args.arg_sql)
@@ -630,10 +636,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     // gated by log::log_enabled!(log::Level::Debug) to avoid the
     // relatively expensive overhead of generating the debug string
-    // for the optimization state struct
+    // for the optimization flags struct
     let debuglog_flag = log::log_enabled!(log::Level::Debug);
     if debuglog_flag {
-        log::debug!("Optimization state: {optimization_state:?}");
+        log::debug!("Optimization flags: {optflags:?}");
         log::debug!(
             "Delimiter: {delim} Infer_schema_len: {infer_len} try_parse_dates: {parse_dates} \
              ignore_errors: {ignore_errors}, low_memory: {low_memory}, float_precision: \
@@ -732,7 +738,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             let lf = LazyCsvReader::new(table)
                 .with_has_header(true)
                 .with_missing_is_null(true)
-                .with_comment_prefix(comment_char.as_deref())
+                .with_comment_prefix(comment_char.clone())
                 .with_null_values(Some(NullValues::AllColumns(rnull_values.clone())))
                 .with_separator(tsvssv_delim(table, delim))
                 .with_infer_schema_length(Some(args.flag_infer_len))
@@ -742,7 +748,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 .with_decimal_comma(args.flag_decimal_comma)
                 .with_low_memory(args.flag_low_memory)
                 .finish()?;
-            ctx.register(table_name, lf.with_optimizations(optimization_state));
+            ctx.register(table_name, lf.with_optimizations(optflags));
         }
     }
 
