@@ -100,6 +100,7 @@ fn main() -> QsvExitCode {
     dedup       Remove redundant rows
     describegpt Infer extended metadata using a LLM
     diff        Find the difference between two CSVs
+    edit        Replace a cell's value specified by row and column
     enum        Add a new column enumerating CSV lines
     excel       Exports an Excel sheet to a CSV
     exclude     Excludes the records in one CSV from another
@@ -189,7 +190,7 @@ fn main() -> QsvExitCode {
 
     #[cfg(all(feature = "to", feature = "feature_capable"))]
     enabled_commands
-        .push_str("    to          Convert CSVs to PostgreSQL/XLSX/Parquet/SQLite/Data Package\n");
+        .push_str("    to          Convert CSVs to PostgreSQL/XLSX/SQLite/Data Package\n");
 
     enabled_commands.push_str(
         "    transpose   Transpose rows/columns of CSV data
@@ -332,6 +333,7 @@ enum Command {
     Dedup,
     Describegpt,
     Diff,
+    Edit,
     Enum,
     Excel,
     Exclude,
@@ -419,6 +421,7 @@ impl Command {
             Command::Dedup => cmd::dedup::run(argv),
             Command::Describegpt => cmd::describegpt::run(argv),
             Command::Diff => cmd::diff::run(argv),
+            Command::Edit => cmd::edit::run(argv),
             Command::Enum => cmd::enumerate::run(argv),
             Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
