@@ -157,6 +157,10 @@ impl SelectorParser {
             self.bump();
             self.parse_quoted_name()?
         } else {
+            if self.cur() == Some('_') {
+                self.bump();
+                return Ok(OneSelector::End);
+            }
             self.parse_name()
         };
         Ok(if self.cur() == Some('[') {
