@@ -37,12 +37,14 @@ fn setup(name: &str, headers: bool) -> Workdir {
         svec!["New York", "NY"],
         svec!["San Francisco", "CA"],
         svec!["Buffalo", "NY"],
+        svec!("NEW YORK", "NY"),
     ];
     let mut places = vec![
         svec!["Boston", "Logan Airport"],
         svec!["Boston", "Boston Garden"],
         svec!["Buffalo", "Ralph Wilson Stadium"],
         svec!["Orlando", "Disney World"],
+        svec!["New York", "Empire State Building"],
     ];
     if headers {
         cities.insert(0, svec!["city", "state"]);
@@ -72,17 +74,54 @@ exclude_test!(exclude, |wrk: Workdir,
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = make_rows(
         headers,
-        vec![svec!["New York", "NY"], svec!["San Francisco", "CA"]],
+        vec![
+            // svec!["New York", "NY"],
+            svec!["San Francisco", "CA"],
+            svec!["NEW YORK", "NY"],
+        ],
     );
     assert_eq!(got, expected);
 });
 
+exclude_test!(exclude_casei, |wrk: Workdir,
+                              mut cmd: process::Command,
+                              headers: bool| {
+    cmd.arg("--ignore-case");
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = make_rows(headers, vec![svec!["San Francisco", "CA"]]);
+    assert_eq!(got, expected);
+});
+
 exclude_test!(include, |wrk: Workdir,
                         mut cmd: process::Command,
                         headers: bool| {
     cmd.arg("-v");
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
-    let expected = make_rows(headers, vec![svec!["Boston", "MA"], svec!["Buffalo", "NY"]]);
+    let expected = make_rows(
+        headers,
+        vec![
+            svec!["Boston", "MA"],
+            svec!["New York", "NY"],
+            svec!["Buffalo", "NY"],
+        ],
+    );
+    assert_eq!(got, expected);
+});
+
+exclude_test!(include_casei, |wrk: Workdir,
+                              mut cmd: process::Command,
+                              headers: bool| {
+    cmd.arg("-v").arg("--ignore-case");
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = make_rows(
+        headers,
+        vec![
+            svec!["Boston", "MA"],
+            svec!["New York", "NY"],
+            svec!["Buffalo", "NY"],
+            svec!["NEW YORK", "NY"],
+        ],
+    );
     assert_eq!(got, expected);
 });
 
@@ -121,3 +160,39 @@ fn exclude_utf8_issue778_positions_aliases() {
 
     assert_eq!(got, expected.trim_end());
 }
+
+#[test]
+fn exclude_1497_empty_fields() {
+    let wrk = Workdir::new("exclude_1497_empty_fields");
+
+    wrk.create(
+        "data.csv",
+        vec![
+            svec!["id", "start", "end"],
+            svec!["1", "2001", "2003"],
+            svec!["2", "2004", "2006"],
+            svec!["3", "2006", ""],
+            svec!["4", "2007", "2010"],
+        ],
+    );
+
+    wrk.create(
+        "skip.csv",
+        vec![
+            svec!["id", "start", "end"],
+            svec!["2", "2004", "2006"],
+            svec!["3", "2006", ""],
+        ],
+    );
+
+    let mut cmd = wrk.command("exclude");
+    cmd.arg("id,end")
+        .arg("data.csv")
+        .arg("id,end")
+        .arg("skip.csv");
+
+    let got: String = wrk.stdout(&mut cmd);
+    let expected = "id,start,end\n1,2001,2003\n4,2007,2010";
+
+    assert_eq!(got, expected);
+}
