@@ -41,9 +41,9 @@ fn index_outdated_stats() {
         "in.csv",
         vec![
             svec!["letter", "number"],
-            svec!["a", "1"],
+            svec!["a", "3"],
             svec!["b", "2"],
-            svec!["c", "3"],
+            svec!["c", "1"],
         ],
     );
 
@@ -55,6 +55,8 @@ fn index_outdated_stats() {
     )
     .unwrap();
 
+    std::thread::sleep(std::time::Duration::from_secs(1));
+
     // even if the index is stale, stats should succeed
     // as the index is automatically updated
     let mut cmd = wrk.command("stats");
@@ -70,6 +72,7 @@ fn index_outdated_stats() {
             "min",
             "max",
             "range",
+            "sort_order",
             "min_length",
             "max_length",
             "mean",
@@ -82,12 +85,44 @@ fn index_outdated_stats() {
             "sparsity"
         ],
         svec![
-            "letter", "String", "true", "", "a", "c", "", "1", "1", "", "", "", "", "", "0", "",
+            "letter",
+            "String",
+            "true",
+            "",
+            "a",
+            "c",
+            "",
+            "Ascending",
+            "1",
+            "1",
+            "",
+            "",
+            "",
+            "",
+            "",
+            "0",
+            "",
             "0"
         ],
         svec![
-            "number", "Integer", "", "6", "1", "3", "2", "1", "1", "2", "0.4714", "0.8165",
-            "0.6667", "40.8248", "0", "", "0"
+            "number",
+            "Integer",
+            "",
+            "6",
+            "1",
+            "3",
+            "2",
+            "Descending",
+            "1",
+            "1",
+            "2",
+            "0.4714",
+            "0.8165",
+            "0.6667",
+            "40.8248",
+            "0",
+            "",
+            "0"
         ],
     ];
 
